@@ -1,13 +1,16 @@
 import click
+import os
 import pdb
 import sys
 
-from stoobly_agent.app.cli.helpers.handle_test_service import SessionContext, exit_on_failure, handle_on_test_response, print_request
+from stoobly_agent.app.cli.helpers.handle_replay_service import DEFAULT_FORMAT, JSON_FORMAT, handle_before_replay, print_request
+from stoobly_agent.app.cli.helpers.handle_test_service import SessionContext, exit_on_failure, handle_test_complete, handle_test_session_complete 
 from stoobly_agent.app.cli.helpers.print_service import print_scenarios, select_print_options
 from stoobly_agent.app.cli.helpers.test_facade import TestFacade
 from stoobly_agent.app.cli.helpers.context import ReplayContext
 from stoobly_agent.app.settings import Settings
-from stoobly_agent.config.constants import alias_resolve_strategy, test_filter, test_strategy
+from stoobly_agent.config.constants import alias_resolve_strategy, env_vars, test_filter, test_strategy
+from stoobly_agent.lib import logger
 
 from .helpers.scenario_facade import ScenarioFacade
 from .helpers.validations import *
@@ -53,13 +56,22 @@ def create(**kwargs):
     help='Strategy for resolving dynamic values for aliases.'
 )
 @click.option('--assign', multiple=True, help='Assign alias values. Format: <NAME>=<VALUE>')
+@click.option('--format', default=DEFAULT_FORMAT, type=click.Choice([DEFAULT_FORMAT, JSON_FORMAT]), help='Format replay response.')
 @click.option('--group-by', help='Repeat for each alias name.')
 @click.option('--lifecycle-hooks-script-path', help='Path to lifecycle hooks script.')
+@click.option(
+    '--log-level', default=logger.WARNING, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), 
+    help='''
+        Log levels can be "debug", "info", "warning", or "error"
+    '''
+)
 @click.option('--record', is_flag=True, default=False, help='Replay and record scenario.')
 @click.option('--scenario-key', help='Record to scenario.')
 @click.option('--trace-id', help='Use existing trace.')
 @click.argument('key')
 def replay(**kwargs):
+    os.environ[env_vars.LOG_LEVEL] = kwargs['log_level']
+
     validate_scenario_key(kwargs['key'])
 
     if kwargs.get('scenario_key'):
@@ -69,7 +81,14 @@ def replay(**kwargs):
 
         validate_scenario_key(kwargs['scenario_key'])
 
-    kwargs['on_response'] = print_request
+    __assign_default_alias_resolve_strategy(kwargs)
+
+    kwargs['before_replay'] = lambda context: handle_before_replay(
+      context, kwargs['format']
+    )
+    kwargs['after_replay'] = lambda context: print_request(
+        context, kwargs['format']
+    )
 
     scenario = ScenarioFacade(Settings.instance())
     scenario.replay(kwargs.get('key'), kwargs)
@@ -85,20 +104,42 @@ def replay(**kwargs):
     help='Strategy for resolving dynamic values for aliases.'
 )
 @click.option('--assign', multiple=True, help='Assign alias values. Format: <NAME>=<VALUE>')
-@click.option('--filter', default=test_filter.ALL, type=click.Choice([test_filter.ALL, test_filter.ALIAS, test_filter.LINK]), help='For iterable responses, selectively test properties.')
+@click.option(
+    '--filter', 
+    default=test_filter.ALL, 
+    type=click.Choice([test_filter.ALL, test_filter.ALIAS, test_filter.LINK]), 
+    help='For iterable responses, selectively test properties.'
+)
+@click.option('--format', default=DEFAULT_FORMAT, type=click.Choice([DEFAULT_FORMAT, JSON_FORMAT]), help='Format replay response.')
 @click.option('--group-by', help='Repeat for each alias name.')
 @click.option('--lifecycle-hooks-script-path', help='Path to lifecycle hooks script.')
+@click.option(
+    '--log-level', default=logger.WARNING, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), 
+    help='''
+        Log levels can be "debug", "info", "warning", or "error"
+    '''
+)
 @click.option('--report-key', help='Save to report.')
-@click.option('--strategy', default=test_strategy.DIFF, type=click.Choice([test_strategy.CUSTOM, test_strategy.DIFF, test_strategy.FUZZY]), help='How to test responses.')
+@click.option(
+    '--strategy', 
+    default=test_strategy.DIFF, 
+    type=click.Choice([test_strategy.CUSTOM, test_strategy.DIFF, test_strategy.FUZZY]), 
+    help='How to test responses.'
+)
 @click.option('--trace-id', help='Use existing trace.')
 @click.argument('key')
 def test(**kwargs):
+    os.environ[env_vars.LOG_LEVEL] = kwargs['log_level']
+    logger.Logger.reload()
+
     settings = Settings.instance()
     scenario_key = validate_scenario_key(kwargs['key'])
 
     if kwargs.get('report_key'):
         validate_report_key(kwargs['report_key'])
 
+    __assign_default_alias_resolve_strategy(kwargs)
+
     session_context: SessionContext = { 
         'aggregate_failures': kwargs['aggregate_failures'], 
         'passed': 0, 
@@ -106,13 +147,19 @@ def test(**kwargs):
         'test_facade': TestFacade(settings), 
         'total': 0 
     }
-    kwargs['on_response'] = lambda context: __handle_on_test_response(
-        context, session_context 
+
+    kwargs['before_replay'] = lambda context: handle_before_replay(
+      context, kwargs['format']
+    )
+    kwargs['after_replay'] = lambda context: __handle_on_test_response(
+        context, session_context, kwargs['format']
     )
 
     scenario = ScenarioFacade(settings)
     scenario.test(kwargs['key'], kwargs)
 
+    handle_test_session_complete(session_context)
+
     exit_on_failure(session_context)
 
 @scenario.command(
@@ -164,8 +211,13 @@ def show(**kwargs):
 
     print_scenarios([scenario_response], **print_options)
 
-def __handle_on_test_response(replay_context: ReplayContext, session_context: SessionContext):
-    handle_on_test_response(replay_context, session_context)
+def __handle_on_test_response(replay_context: ReplayContext, session_context: SessionContext, format = None):
+    handle_test_complete(replay_context, session_context, format)
 
     if not session_context['aggregate_failures']:
-        exit_on_failure(session_context)
\ No newline at end of file
+        exit_on_failure(session_context, False)
+
+def __assign_default_alias_resolve_strategy(kwargs):
+    # If we have assigned values to aliases, it's likely we want to also have them resolved
+    if len(kwargs['assign']) > 0 and kwargs['alias_resolve_strategy'] == alias_resolve_strategy.NONE:
+        kwargs['alias_resolve_strategy'] = alias_resolve_strategy.FIFO
\ No newline at end of file
