@@ -17,4 +17,4 @@ ENV = 'STOOBY_AGENT_ENV'
 HTTP_PROXY = 'HTTP_PROXY'
 HTTPS_PROXY = 'HTTPS_PROXY'
 LOG_LEVEL = 'STOOBLY_AGENT_LOG_LEVEL'
-TEST_SCRIPT = 'TEST_SCRIPT'
+NO_PROXY = 'NO_PROXY'
\ No newline at end of file
